@@ -8,4 +8,7 @@ from spongeWebPy.all_ceRNAInteraction import *
 from spongeWebPy.find_miRNA import *
 from spongeWebPy.get_GeneCount import *
 from spongeWebPy.specific_ceRNA import *
-from spongeWebPy.specific_ceRNAInteraction import *
\ No newline at end of file
+from spongeWebPy.specific_ceRNAInteraction import *
+from spongeWebPy.geneOntology import *
+from spongeWebPy.hallmarks import *
+from spongeWebPy.overview import *
\ No newline at end of file
